#!/usr/bin/python

import os, re, string, sys
from optparse import OptionParser

from pysqlite2 import dbapi2 as sqlite
#import sqlite

usage = "usage: %prog -i [dbfile] [options]"
version = "1.1 by Garrett Gee <garrett - at - garrettgee.com>"
parser = OptionParser(usage=usage,version=version)
parser.add_option("-i", "--inputfile", dest="inputfile", help="dat input file")
parser.add_option("-o", "--outputfile", dest="outputfile", help="if not defined, will create html file based on filename")
parser.add_option("-v", "--verbose", action="store_true", dest="verbose", help="")
parser.add_option("-d", "--debug", action="store_true", dest="debug", help="")

(options, args) = parser.parse_args()

if (not (options.inputfile)) or (not os.path.isfile(options.inputfile)):
    parser.print_help()
    sys.exit()

dbfile = options.inputfile
txtfile = options.outputfile
verbose = options.verbose
debug = options.debug
#------------------------------------------
if not (txtfile):
    (txtfile,ext) = os.path.splitext(dbfile)
    txtfile = txtfile + "-auto.html"
    
if debug:
    print "Inputfile: " + dbfile    
    print "Outputfile: " + txtfile

if os.path.isfile(txtfile):
    ##this should be a choice box
    print "Removing old " + txtfile
    os.remove(txtfile)    
#------------------------------------------
cx = sqlite.connect(dbfile)
cu = cx.cursor()

fh = open(txtfile, "a")
fh.write("<html><head><title>Auto Nessus Report for " + dbfile + "</title></head><body>\n\n")

#high - apache chunked handling vuln - 11030
cu.execute("select IP, port, notes from nessus where pluginid=\"11030\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Apache Remote Code Execution (High-None):</b><br>\n")
    fh.write("Based on version - Chunked handling vulnerability</b><br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        cu.execute("select notes from nessus where pluginid=\"10107\" and IP = ? and port = ? limit 1;", (ip, port))
        support = cu.fetchone()
        
        support = support[0]
        support = string.split(support, "\\n\\n")
        support = support[-2]
        support = string.replace(support, "\\r", "")
        data.append(ip + ":" + port + " - " + support)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#high - Apache < 1.3.27 - 11137
cu.execute("select IP, port, notes from nessus where pluginid=\"11137\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Apache < 1.3.27 (High):</b><br>\n")
    fh.write("Multiple vulnerabilities</b><br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        cu.execute("select notes from nessus where pluginid=\"10107\" and IP = ? and port = ? limit 1;", (ip, port))
        support = cu.fetchone()
        
        support = support[0]
        support = string.split(support, "\\n\\n")
        support = support[-2]
        support = string.replace(support, "\\r", "")
        data.append(ip + ":" + port + " - " + support)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#med - telnet running - 10281
cu.execute("select IP, port, notes from nessus where pluginid=\"10281\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Telnet Enabled (Med):</b><br>\n")
    fh.write("Clear text authentication<br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        support = string.split(notes, "\\n\\n")
        support = support[-2].strip()
        support = string.replace(support, "------------------------------ snip ------------------------------", "")
        support = string.replace(support, "\\n", "")
        data.append(ip + ":" + port + " - " + support)
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#med - basic auth over http - 24260
cu.execute("select IP, port, notes from nessus where pluginid=\"24260\" and notes like \"%www-authenticate: basic%\" and notes like \"%SSL : no%\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>HTTP Basic Auth (Med):</b><br>\n")
    fh.write("Clear text authentication<br>\n")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - Terminal Service running without SSL - 18405 
cu.execute("select IP, port, notes from nessus where pluginid=\"18405\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Terminal Service running without SSL (Med):</b><br>\n")
    fh.write("MITM the client<br>\n")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - ssh protocol v1
cu.execute("select IP, port, notes from nessus where pluginid=\"10882\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>SSH protocol v1 allowed (Med):</b><br>\n")
    fh.write("MITM the client<br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        cu.execute("select IP, port, notes from nessus where pluginid=\"10881\" and ip = ? limit 1;", (ip,))
        support = cu.fetchone()
        
        support = support[-1]
        support = string.split(support, "\\n\\n")
        support = support[-4] + support[-3]
        support = string.replace(support, "\\n", " ")
        data.append(ip + ":" + port + " - " + support)
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - openssh version < 5
cu.execute("select IP, port, notes from nessus where pluginid=\"31737\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>OpenSSH version < 5 (Med):</b><br>\n")
    fh.write("Vulnerable to X11 Forwarding Session Hijacking<br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        support = string.split(notes, "\\n\\n")
        support = support[-2].strip()
        data.append(ip + ":" + port + " - " + support)
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - ssl cert expired or close to expiring
cu.execute("select IP, port, notes from nessus where pluginid=\"15901\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>SSL certificate has already expired or will expire shortly (Med):</b><br>\n")
    fh.write("Trust / Authority<br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        support = string.split(notes, "\\n\\n")
        support = support[9:]
        a = ""
        for i in support:
            i = string.replace(i, "\\n", "<br>")
            a = a + i
        support = a
        
        data.append(ip + ":" + port + " - " + support)
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#med - ssl protocol v2 allowed - 20007
cu.execute("select IP, port, notes from nessus where pluginid=\"20007\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>SSL protocol v2 allowed (Med):</b><br>\n")
    fh.write("MITM<br>\n")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")    

#med - Weak SSL ciphers - 26928 
#ssl ciphers aggregated and ip:ports aggregated in a table
#put each ssl cipher set in a list and then print them all out 
#put each ip:port in a list and then print them all out
cu.execute("select IP, port, notes from nessus where pluginid=\"26928\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Weak SSL ciphers (Med):</b><br>\n")
    fh.write("Weak crypto<br>")
    fh.write("still need to figure out how to parse out the sslv2/sslv3/tlsv1 ciphers to put into a list<br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        support = string.split(notes, "\\n\\n")
        #print list
        support = support[-4].strip()
        support = string.split(support, "\\n")
        #print support
        #extract the data list into one giant string
        #for each list item, input a \n
        
        #compare the list string
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - SSL certificate has been signed using a weak hash algorithm - 35291
cu.execute("select IP, port, notes from nessus where pluginid=\"35291\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>SSL certificate signed with weak hash algorith - MD2, MD4, or MD5 (Med):</b><br>\n")
    fh.write("Attacker generate own valid SSL cert for same domain - spoofing type attack<br>")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - DNS server allows recursive queries - 10539
cu.execute("select IP, port, notes from nessus where pluginid=\"10539\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>DNS server allows recursive queries (Med-None):</b><br>\n")
    fh.write("If internal nameserver -> ignore. If remote nameserver->cache poisoning attack<br>")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#med - dns cache snooping attack - 12217
cu.execute("select IP, port, notes from nessus where pluginid=\"12217\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>DNS cache snooping attack (Med):</b><br>\n")
    fh.write("Attacker could determine which hosts have been recently resolved - http://www.rootsecure.net/content/downloads/pdf/dns_cache_snooping.pdf<br>")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#med - IBM WebSphere Application Server < 6.0.2 Fix Pack 35 - 38978
cu.execute("select IP, port, notes from nessus where pluginid=\"38978\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>IBM WebSphere Application Server < 6.0.2 Fix Pack 35 (Med):</b><br>\n")
    fh.write("Multiple vulnerabilities<br>")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - IBM WebSphere Application Server < 6.0.2 Fix Pack 33 - 38978
cu.execute("select IP, port, notes from nessus where pluginid=\"36132\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>IBM WebSphere Application Server < 6.0.2 Fix Pack 33 (Med):</b><br>\n")
    fh.write("Multiple vulnerabilities<br>")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - apache < 1.3.41 multiple vulns - 31408
cu.execute("select IP, port, notes from nessus where pluginid=\"31408\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Apache < 1.3.41 (Med):</b><br>\n")
    fh.write("Multiple vulnerabilities<br>")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        cu.execute("select notes from nessus where pluginid=\"10107\" and IP = ? and port = ? limit 1;", (ip, port))
        support = cu.fetchone()
        
        support = support[0]
        support = string.split(support, "\\n\\n")
        support = support[-2]
        support = string.replace(support, "\\r", "")
        data.append(ip + ":" + port + " - " + support)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

#med - Apache < 1.3.29 multiple vulns - 11915
cu.execute("select IP, port, notes from nessus where pluginid=\"11915\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Apache < 1.3.29 (Med):</b><br>\n")
    fh.write("Multiple vulnerabilities<br>")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        cu.execute("select notes from nessus where pluginid=\"10107\" and IP = ? and port = ? limit 1;", (ip, port))
        support = cu.fetchone()
        
        support = support[0]
        support = string.split(support, "\\n\\n")
        support = support[-2]
        support = string.replace(support, "\\r", "")
        data.append(ip + ":" + port + " - " + support)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#med - Apache that is less that 2.0.49 or 1.3.31. - 12280
cu.execute("select IP, port, notes from nessus where pluginid=\"12280\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Apache < 1.3.31 or < 2.0.49 (Low):</b><br>\n")
    fh.write("Denial of Service Attack<br>")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        cu.execute("select notes from nessus where pluginid=\"10107\" and IP = ? and port = ? limit 1;", (ip, port))
        support = cu.fetchone()
        
        support = support[0]
        support = string.split(support, "\\n\\n")
        support = support[-2]
        support = string.replace(support, "\\r", "")
        data.append(ip + ":" + port + " - " + support)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#low - DCE/RPC enumeration - 10736
cu.execute("select IP, port, notes from nessus where pluginid=\"10736\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>DCE/RPC connections allowed (Low):</b><br>\n")
    fh.write("Service enumeration<br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        #uncomment below f you want the data from the service enumeration. warning - lots of data
        a = ""
        support = string.split(notes, "\\n\\n")
        support = support[9:]
        for i in support:
            i = string.replace(i, "\\n", "<br>")
            a = a + i + "<br>"
        support = a
        data.append("<b>" + ip + "</b>:" + port + " - " + support)
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#low - ONC RPC service enumeration - 11111
cu.execute("select IP, port, notes from nessus where pluginid=\"11111\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>ONC RPC RPC connections allowed (Low):</b><br>\n")
    fh.write("Service enumeration<br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        #uncomment below f you want the data from the service enumeration. warning - lots of data
        support = string.split(notes, "\\n\\n")
        support = support[7:]
        for i in support:
            i = string.replace(i, "\\n", "<br>")
            a = a + i + "<br>"
        support = a
        data.append("<b>" + ip + "</b>:" + port + " - " + support)
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#low Windows null session allowed - 26920
cu.execute("select IP, port, notes from nessus where pluginid=\"26920\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>Windows NULL sessions allowed (Low):</b><br>\n")
    fh.write("Can login to system with a NULL session<br>")
    devices = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")
    
#low - DNS server discloses host name - 35371
cu.execute("select IP, port, notes from nessus where pluginid=\"35371\" order by IP;")
res = cu.fetchall()
if res:
    fh.write("<b>DNS server discloses host name (Low):</b><br>\n")
    fh.write("Information leak<br>\n")
    devices = []
    data = []
    
    for row in res:
        ip = row[0]
        port = str(row[1])
        notes = row[2]
        
        devices.append(ip + ":" + port)
        
        support = string.split(notes, "\\n\\n")
        support = support[-2]
        data.append(ip + ":" + port + " - " + support)
    
    fh.write("<table border=\"1\"><tr><th>" + str(len(devices)) + " devices</th><th>supporting data</th>\n")
    fh.write("<tr><td>")
    for i in devices:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("<td>")
    for i in data:
        fh.write(i + "<br>")
    fh.write("</td>\n")
    fh.write("</tr>")
    fh.write("</table>")
    fh.write("<br>\n\n")

fh.write("</body></html>")
fh.close()

