#!/usr/bin/python

import os, re, sys
from optparse import OptionParser

from pysqlite2 import dbapi2 as sqlite

usage = "usage: %prog -i [dbfile] [options]"
version = "1.0 by Garrett Gee <garrett - at - garrettgee.com>"
parser = OptionParser(usage=usage,version=version)
parser.add_option("-i", "--inputfile", dest="inputfile", help="dat input file")
parser.add_option("-o", "--outputfile", dest="outputfile", help="if not defined, will create html file based on filename")
parser.add_option("-v", "--verbose", action="store_true", dest="verbose", help="")
parser.add_option("-d", "--debug", action="store_true", dest="debug", help="")

(options, args) = parser.parse_args()

if (not (options.inputfile)) or (not os.path.isfile(options.inputfile)):
    parser.print_help()
    sys.exit()

dbfile = options.inputfile
htmlfile = options.outputfile
verbose = options.verbose
debug = options.debug
#------------------------------------------
if not (htmlfile):
    (htmlfile,ext) = os.path.splitext(dbfile)
    htmlfile = htmlfile + ".html"
    
if debug:
    print "Inputfile: " + dbfile    
    print "Outputfile: " + htmlfile

if os.path.isfile(htmlfile):
    ##this should be a choice box
    print "Removing old " + htmlfile
    os.remove(htmlfile)    
#------------------------------------------
def htmlprint(row):
    #ip, service,port,protocol,pluginid,sevlevel,notes
##ip:port (linkable) :service:sev:output / pluginid (linkable)

#for plugin id
#http://www.nessus.org/plugins/index.php?view=single&id=10092

    ip = row[0]
    service = row[1]
    port = row[2]
    protocol = row[3]
    pluginid = row[4]
    sevlevel = row[5]
    notes = row[6]
    
    html = '<tr><td>' + ip + '</td>'
    
    #html = "<b>" + port + "/" + protocol + "</b> - " + service
    
    if protocol == "tcp":
        html = html + '<td><a href="http://'+ ip + ':' + port + '">' + port + "/" + protocol + "</a></td>"
    else:
        html = html + "<td>" + port + "/" + protocol + "</td>"
        
    html = html + "<td>" + service + "</td>"
        
    if sevlevel != "":
        html = html + "<td>" + sevlevel + "</td>"
        
        notes = re.sub(r'\\(n)', "<br>", notes)
        notes = notes + '<br>Nessus Plugin: <a href="http://www.nessus.org/plugins/index.php?view=single&'+ pluginid + '">' + pluginid + '</a>'
        html = html + "<td>" + notes + "</td>"
    else:
        html = html + "<td>unknown</td><td></td>"
        
    html = html + '</tr>\n'
    
    return html
#------------------------------------------
cx = sqlite.connect(dbfile)
cu = cx.cursor()

fh = open(htmlfile, "a")

header = "<html>\n<head>\n<title>Nessus Report for " + dbfile + "</title>\n"
header = header + '<style type="text/css">\n'
header = header + 'table.sortable { border-spacing: 0; border: 1px solid #000; border-collapse: collapse; font-size: 8pt; }\n'
header = header + 'table.sortable th, table.sortable td { text-align: left; padding: 2px 4px 2px 4px; width: 1000px; border-style: solid; border-color: #444; }\n'
header = header + 'table.sortable th { border-width: 0px 1px 1px 1px; background-color: #ccc; }\n'
header = header + 'table.sortable td { border-width: 0px 1px 1px 1px;} \n'
header = header + '</style>\n'
header = header + '<script type="text/javascript" src="sorttable.js"></script>\n'
header = header + "</head>\n<body>\n"
fh.write(header)

htmltable = '<table class="sortable" id="anyid" cellpadding="1" cellspacing="1">\n'
htmltable = htmltable + '<tr><th>IP</th><th>Port/Protocol</th><th>Service</th><th>Severity</th><th class="sorttable_nosort">Output</th></tr>\n'
fh.write(htmltable)

##id INTEGER PRIMARY KEY, \
##IP VARCHAR(15), \
##service VARCHAR(20), \
##port INTEGER, \
##protocol VARCHAR(3), \
##pluginid INTEGER, \
##sevlevel VARCHAR(20), \
##notes VARCHAR(1000) \


#asc doesnt understand IP notation for sorting, do I want to make the IP a number via that conversion script?
cu.execute("select distinct IP from nessus order by IP asc")
res_ip = cu.fetchall()
for row_ip in res_ip:
    ip = row_ip[0]
    
    #TCP
    cu.execute("select ip, service, port, protocol, pluginid, sevlevel, notes from nessus where IP = ? and protocol = \"tcp\" and port != \"\"", (ip,))
    res_tcp = cu.fetchall()
    for row_tcp in res_tcp:
        ip = row_tcp[0]
        service = row_tcp[1]
        port = str(row_tcp[2])
        protocol = row_tcp[3]
        pluginid = str(row_tcp[4])
        sevlevel = row_tcp[5]
        notes = row_tcp[6]        
        if not sevlevel:
            sevlevel = ""
        
        html = htmlprint((ip, service, port, protocol, pluginid, sevlevel, notes))
        fh.write(html)
        
##    #UDP
##    cu.execute("select distinct port from nessus where IP = ? and protocol = \"udp\" and port != \"\"", (ip,))
##    res_udp = cu.fetchall()
##    udplist = ""
##    first = 1
##    for row_udp in res_udp:
##        port = str(row_udp[0])
##        if first:
##            udplist = port
##            first = 0
##        else:
##            udplist = udplist + ", " + port
##    if udplist == "":
##        udplist = "None"                
##    
##    line = ip + "|" + tcplist + "|" + udplist
##    fh.write(line + "\n")
##    if verbose:            
##        print line

htmltable = '</table>\n'
fh.write(htmltable)

footer = "</body>"
fh.write(footer)

fh.close()